@@ -195,7 +195,8 @@ class RDYFile:
     def __repr__(self):
         return "Filename: %s, T0: %s, Duration: %s" % (self.filename,
                                                        str(self.t0),
-                                                       str(datetime.timedelta(seconds=self.duration)))
+                                                       str(datetime.timedelta(seconds=self.duration)) if self.duration
+                                                       else "N/A")
 
     def _do_candidate_search(self, osm_xy: np.ndarray, track_xy: np.ndarray, hor_acc: np.ndarray):
         """ Internal method to search for candidate edges for map matching
